Welcome to RattleSNP's documentation!
=====================================


.. image:: _images/rattleSNP_logo.png
   :target: _images/rattleSNP_logo.png
   :align: center
   :alt: RattleSNP Logo

Best SNP calling workflow

.. toctree::
   :caption: About RattleSNP
   :name: about_rattleSNP
   :maxdepth: 2

   ABOUT.rst

.. toctree::
   :caption: Install
   :name: install
   :maxdepth: 2

   INSTALL.rst

.. toctree::
   :caption: Defining Workflows
   :name: defining_workflows
   :maxdepth: 2

   WORKFLOWS.rst

.. toctree::
   :caption: Project Info
   :name: project_info
   :maxdepth: 1

   PROJECT.rst

.. toctree::
   :caption: FAQ
   :name: faq_questions
   :maxdepth: 2

   FAQ.rst

.. toctree::
   :caption: API
   :name: api_rattleSNP
   :maxdepth: 2

   click.rst

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
